pyfisheye
=========

Welcome to the pyfisheye documentation!

pyfisheye is a Python library for automatic calibration of fisheye and omnidirectional cameras, offering fast and accurate mapping between image and world coordinates.

Pyfisheye is based on [1]_ and [2]_.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   demonstration
   calibration
   examples
   projection
   technical
   contributing
   modules

References
----------

.. [1] Scaramuzza et al., "Omnidirectional Camera Calibration," IEEE IROS 2006, https://doi.org/10.1109/IROS.2006.282372
.. [2] Urban et al., "Improved omnidirectional camera calibration," ISPRS Journal 2015, https://doi.org/10.1016/j.isprsjprs.2015.06.005
